summary refs log tree commit diff stats
path: root/tests/js/tbyvar.nim
diff options
context:
space:
mode:
authorflywind <xzsflywind@gmail.com>2022-01-04 20:29:50 +0800
committerGitHub <noreply@github.com>2022-01-04 13:29:50 +0100
commit9df195ef581879cf9e5c3c3154755bd1dba677c6 (patch)
tree71dc955a6976558b3cb47f98443093b388c1ce36 /tests/js/tbyvar.nim
parent1869826668e2e3a0fd69cc1b69fb12b07993e417 (diff)
downloadNim-9df195ef581879cf9e5c3c3154755bd1dba677c6.tar.gz
style usages part one (openarray => openArray) (#19321)
* style usages (openArray)

* revert doc changes
Diffstat (limited to 'tests/js/tbyvar.nim')
-rw-r--r--tests/js/tbyvar.nim4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/js/tbyvar.nim b/tests/js/tbyvar.nim
index a4c60b0b3..93724a2f1 100644
--- a/tests/js/tbyvar.nim
+++ b/tests/js/tbyvar.nim
@@ -39,9 +39,9 @@ proc main =
 
 main()
 
 # Test: pass var seq to var openarray
 var s = @[2, 1]
-proc foo(a: var openarray[int]) = a[0] = 123
+proc foo(a: var openArray[int]) = a[0] = 123
 
 proc bar(s: var seq[int], a: int) =
   doAssert(a == 5)
@@ -39,9 +39,9 @@ proc main =
 main()
 
-# Test: pass var seq to var openarray
+# Test: pass var seq to var openArray
 var s = @[2, 1]